@@ -1,5 +1,6 @@
 import pytest
 
+import warnings
 import json
 import six
 import jsonschema
@@ -10,6 +11,29 @@ import logging
 logging.basicConfig(level=logging.DEBUG)
 
 
+@pytest.mark.parametrize(
+    "version, warn",
+    [
+        ("http://json-schema.org/schema#", True),
+        ("http://json-schema.org/draft-03/schema", False),
+        ("http://json-schema.org/draft-04/schema", False),
+        ("http://json-schema.org/draft-06/schema", True),
+        ("http://json-schema.org/draft-07/schema", True),
+    ],
+)
+def test_warnings_on_schema_version(version, warn):
+    schema = {"$schema": version, "$id": "test", "type": "object", "properties": {}}
+
+    with warnings.catch_warnings(record=True) as w:
+        pjs.ObjectBuilder(schema)
+
+        if warn:
+            assert len(w) == 1
+            assert "Schema version %s not recognized" % version in str(w[-1].message)
+        else:
+            assert len(w) == 0, w[-1].message
+
+
 def test_schema_validation():
     """ Test that the ObjectBuilder validates the schema itself.
     """
@@ -18,7 +42,7 @@ def test_schema_validation():
         "$id": "test",
         "type": "object",
         "properties": {
-            "name": "string",
+            "name": "string",  #  <-- this is invalid
             "email": {"oneOf": [{"type": "string"}, {"type": "integer"}]},
         },
         "required": ["email"],
@@ -378,6 +402,19 @@ def test_attribute_set_via_dict(person_object):
     assert str(name) == "John"
 
 
+def test_keys_can_be_other_pjo_objects(Person, person_object):
+    person_object.lastName = "Smith"
+
+    jane = Person(firstName="Jane", lastName=person_object.lastName)
+
+    assert jane.lastName == person_object.lastName
+
+    # We don't want the names to be the same literal object though.
+    # Changing one after assignment should not change the other
+    jane.lastName = "Borges"
+    assert jane.lastName != person_object.lastName
+
+
 def test_numeric_attribute_validation(Person):
     with pytest.raises(pjs.ValidationError):
         Person(firstName="James", lastName="Bond", age=-10)
@@ -492,3 +529,12 @@ def test_default_values(default):
 
     x = ns.Test()
     assert x.sample == default["default"]
+
+
+def test_justareference_example(markdown_examples):
+
+    builder = pjs.ObjectBuilder(
+        markdown_examples["Just a Reference"], resolved=markdown_examples
+    )
+    ns = builder.build_classes()
+    ns.JustAReference("Hello")
